@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import argparse
 import base64
 import copy
@@ -19,7 +21,12 @@ from .sqla import (
     declarative_to_intermediary,
     metadata_to_intermediary,
 )
-from importlib.metadata import version
+
+if sys.version_info >= (3, 8):
+    from importlib.metadata import version
+else:
+    # importlib.metadata not available for python 3.7
+    from importlib_metadata import version
 
 __version__ = version(__package__)
 
